@@ -1,5 +1,5 @@
 package JSON::Karabiner::Manipulator::Actions::From ;
-$JSON::Karabiner::Manipulator::Actions::From::VERSION = '0.005';
+$JSON::Karabiner::Manipulator::Actions::From::VERSION = '0.006';
 use strict;
 use warnings;
 use JSON;
@@ -71,7 +71,7 @@ sub _add_modifiers {
   my $values = \@_;
   croak "This action already has $mod_type modifiers" if $s->{"has_${mod_type}_modifiers"};
 
-  $s->{data}{modifers}{$mod_type} = \@_;
+  $s->{data}{modifiers}{$mod_type} = \@_;
   $s->{"has_${mod_type}_modifiers"} = 1;
 }
 
@@ -235,7 +235,7 @@ See official L<Karbiner documentation|https://karabiner-elements.pqrs.org/docs/j
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 AUTHOR
 
